#
# spec file for package kstars
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_without lang
Name:           kstars
Version:        3.4.2
Release:        lp152.1.3
Summary:        Desktop Planetarium
# Note for legal: the Apache licensed files in the tarball are for the
# Android version - they're neither built nor installed
# Likewise, the non-commercial files in  kstars-17.04.2/README.images are not
# used nor installed
License:        GPL-2.0-or-later AND GPL-3.0-or-later
Group:          Productivity/Scientific/Astronomy
URL:            https://edu.kde.org/kstars/
Source0:        https://download.kde.org/stable/%{name}/%{name}-%{version}.tar.xz
BuildRequires:  Mesa-devel
BuildRequires:  cfitsio-devel
BuildRequires:  eigen3-devel
BuildRequires:  extra-cmake-modules
BuildRequires:  fdupes
BuildRequires:  gsl-devel
BuildRequires:  kconfig-devel
BuildRequires:  kcrash-devel
BuildRequires:  kdoctools-devel
BuildRequires:  ki18n-devel
BuildRequires:  kio-devel
BuildRequires:  knewstuff-devel
BuildRequires:  knotifications-devel
BuildRequires:  kplotting-devel
BuildRequires:  kwidgetsaddons-devel
BuildRequires:  kxmlgui-devel
BuildRequires:  libindi-devel
BuildRequires:  libnova-devel
BuildRequires:  libraw-devel
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  wcslib-devel
BuildRequires:  xplanet
BuildRequires:  cmake(KF5NotifyConfig)
BuildRequires:  cmake(Qt5Keychain)
BuildRequires:  pkgconfig(Qt5Concurrent)
BuildRequires:  pkgconfig(Qt5DataVisualization)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(Qt5PrintSupport)
BuildRequires:  pkgconfig(Qt5Qml)
BuildRequires:  pkgconfig(Qt5Quick)
BuildRequires:  pkgconfig(Qt5Sql)
BuildRequires:  pkgconfig(Qt5Svg)
BuildRequires:  pkgconfig(Qt5Test)
BuildRequires:  pkgconfig(Qt5WebSockets)
BuildRequires:  pkgconfig(Qt5Xml)
Recommends:     libindi
Recommends:     xplanet
Recommends:     %{name}-lang

%description
KStars is astronomy software. It provides an accurate graphical
simulation of the night sky, for any time and location on Earth.

%lang_package

%prep
%setup -q

%build
%ifarch ppc ppc64
export RPM_OPT_FLAGS="%{optflags} -mminimal-toc"
%endif
%cmake_kf5 -d build
%make_jobs

%install
%kf5_makeinstall -C build
%if %{with lang}
  %find_lang %{name} --with-man --all-name
  %kf5_find_htmldocs
%endif

# Remove static library
rm -f %{buildroot}%{_kf5_libdir}/libhtmesh.a

%fdupes -s %{buildroot}

%files
%license COPYING COPYING.DOC
%doc AUTHORS ChangeLog README.md README.customize README.ephemerides README.images
%dir %{_kf5_appstreamdir}
%dir %{_kf5_configkcfgdir}
%doc %{_kf5_htmldir}/en/kstars/
%{_datadir}/sounds/*.ogg
%{_kf5_applicationsdir}/org.kde.kstars.desktop
%{_kf5_appsdir}/kstars/
%{_kf5_appstreamdir}/org.kde.kstars.appdata.xml
%{_kf5_bindir}/kstars
%{_kf5_configkcfgdir}/kstars.kcfg
%{_kf5_iconsdir}/hicolor/*/*/*
%{_kf5_notifydir}/kstars.notifyrc

%if %{with lang}
%files lang -f %{name}.lang
%license COPYING COPYING.DOC
%endif

%changelog
* Mon Apr 27 2020 wbauer@tmo.at
- Update to 3.4.2
  * http://knro.blogspot.com/2020/04/kstars-v342-is-released.html
  * Reduce memory usage when zooming in FITS Viewer tool
  * Standardize unit and GUI tests for KStars in order to ensure
    reliability and detect any regressions that might affect the
    code
  * Preliminary support for INDIHub project
  * Correct bug in median computation
  * Re-enabled the Jupiter's Moons tool
  * Add a warning if the dust cap is missing instead of total abort
  * Fixed KStars deadlock on disconnecting from INDI server
    (kde#398192, kde#416173)
  * Mount box layout corrected so that everything fits well into
    the window
  * SEP Focus improvements
* Mon Feb 24 2020 wbauer@tmo.at
- Update to 3.4.1
  * Do not calculate download time or send image when upload mode
    is LOCAL
  * Only load FITS Data when we need to use FITSViewer
  * Add small space between buttons to avoid accidental deletes
  * Fix crash on CCD reconnection for those with built-in filter
    wheels
  * Move guide reset button to calibration settings
  * Fixed Equinox and Solstice dates in Calculator (kde#387929)
  * Use QLabel so that text wrap if long
  * Add logging to help debug some capture stalls
* Fri Feb 14 2020 wbauer@tmo.at
- Update to 3.4.0
  * http://knro.blogspot.com/2020/02/kstars-v340-is-released.html
  * Continued work on the linear focusing algorithm
  * Faster Astrometry.net solver
  * Fixed a few memory allocation issues to reduce the process
    memory usage
  * Fixed DSLR ImageToFITS loading when auto convert is used
  * Fixed focus direction for relative DC focusers
  * Improved reliability of setting snoop property for the active
    profile
  * Fixed File name sanitization issues
  * Communication with remote INDI Web Manager is now mostly
    asynchronous
  * Align property labels in the INDI dialog vertically on top
* Thu Jan  2 2020 wbauer@tmo.at
- Update to 3.3.9
  * http://knro.blogspot.com/2020/01/kstars-v339-is-released.html
  * Implemented adjustable and fast stretch controls for mono and
    color images within the FITS Viewer
  * New experimental linear focusing algorithm
  * Improved Focus Module in Ekos by adding autofocus support for
    DSLR's that use manualfocusdrive command by gphoto instead of
    rel_focus_position, for example Nikon Z6
  * Added new western Sky Culture
  * Bugfix for re-connecting a weather device initializes the
    weather display
  * Fix off-by-one bug in stretch
  * Fix minor EBN issues
  * Account for exposure less than 0.001 seconds in the file name
  * Making the Columns in the Align view resize automatically
  * Add markers for the documentation configuration pages, add some
    info about sky cultures
  * Abort plate solving when slewing is detected
  * Fix crash when focused object is either asteroid or comet and
    the data is loaded
  * Fix bug re filter-change-autofocus
  * Reset guiding calibration if the mount moves and "Always Reset
    Guide Calibration" option is set
* Mon Nov 18 2019 wbauer@tmo.at
- Update to 3.3.8
  * Fix dome status for rolloff dome when sending status messages
  * Disable the move to polar message action and just display it as
    a message instead to alert the user
  * Fix another crash in poly plotting. Check if array is empty
  * Adding the polynomial and focus position to the focus graph as
    well as tooltips
  * Fix incorrect labels
  * Use backend instead of type to avoid confusion
  * Add solver and astrometry solver types
  * Add error dialog if ASTAP is not found and open options dialog
    automatically after that
  * Solve crashing in creating WCS file and use simpler WCS update
  * Fix condition where previous values of solver type can cause
    crash in the 3.3.7 version
* Sat Nov  9 2019 wbauer@tmo.at
- Update to 3.3.7
  * http://knro.blogspot.com/2019/11/kstars-v337-released.html
  * New ASTAP integration in the Align module
  * Observatory module: added a dedicated weather widget with live
    plotting for each parameter
  * Further improvements to the FITS loading mechanism which
    resulted in speed ups during sequence capturing
  * Fixed HFR calculation in the FITS Data class
  * Two new Ekos options (dusk and dawn offsets), located in the
    Scheduler option pane
  * Some improvements to PHD2 integration with Ekos
  * Added download time estimation to the capture module
  * Solved several issues with guiding & dithering in both capture
    & scheduling
  * Fixed gain setting in capture module
  * Fixed focus HFR-averaging issue
  * Connect Scheduler sleep timer to Simulation Clock scale change
  * Handling of aborts during parking/unparking of rolloff roofs
    corrected
  * Hitting a constraint sets a job to IDLE instead of COMPLETE so
    that it might be restarted later
  * Update OpenNGC to v20191019
* Mon Sep  9 2019 wbauer@tmo.at
- Update to 3.3.6
  * Fixing a little typo
  * QVector --> std::vector just to resolve the mysterious build
    errors on Windows CI
  * Fix block logic error
  * Fix cross-platform errors
  * Fix wrong variable name
* Sun Sep  8 2019 wbauer@tmo.at
- Update to 3.3.5
  * Add confirmation when deleting index folder, improve GUI a bit
  * Improving Astrometry Conf file support for Linux and OS X
  * Add indi web manager scanner for the local network in the
    profile editor
  * Adding icon for atikbase
  * Initialize the recommended gain properly on startup
    (kde#411638)
  * Add DBus function to get location info
  * Improvements is estimateJobTime
  * Send camera state instead of just temperature
  * Do not set temperature or gain unless supported
  * Send states after defining the device capabilities
  * processMarkSelection should be overridden in align view to
    prevent double clicking from moving the marker by mistake
  * Fix few warnings
  * Improve set coordinates manually by adding switches for JNow
    and J2000 settings
  * Set coordinates manually should always default to RA-DE tab
  * Do not report guiding as started in PHD2::StartGuiding Event
    handler because it will start scheduled capture prematurely
    (before Settle is complete)
  * Use table for statistics to show all channels
  * No need to use double for frequency
  * Add DesktopEntry to notifyrc
  * Compute histogram is median value is missing
  * Median value should be an integer
  * In case setting is missing, use camera value
  * Send settings along with camera info
  * Disable actions when parked
  * Use icons for the menu
  * Use more intuitive telescope popup menu in the sky map
  * Display of weather sensor data added to Observatory module
  * Insert format and gain values in the settings
  * Sync the tip with GUI label
  * Improve set coordinates manually dialog by initializing it to
    the current selected coordinates first
  * Set clicked object to nullptr in order to correctly recenter
    on clicked point
  * Minor UI changes
  * Adding error handling strategy control to Scheduler
  * Filename options selection preserved
  * Further improvements to the auto-park functionality
  * Add support to automatically starting auto-park feature on
    startup to park the mount at a specific time
  * Replace the last overlooked qSort()
  * Replace obsolete methods with non-obsolete ones
  * Fix typos, make the button tooltips translatable
  * Make the tooltips translatable
  * Fix minor typo
  * Add support to reverse axis in mount control panel
  * Add support to profile mappings
  * Fix minor typos
  * Fix i18n()
  * Should be fabs not abs, abs is ambiguous.
  * NOOP --> i18n
  * Add cr3 to list of RAW formats
  * changing name to sky point
  * Fixing bug in Mount Model and Simplifying function
  * Fix using i18n for Sun object
  * Do not set m_wasSlewStarted explicity when issusing GOTO
    command. Wait for IPS_BUSY from mount driver. (kde#410094)
  * Make display format in planet viewer to be dd/MM/yyyy
    (kde#411185)
  * Fix infinite loop
  * Profile wizard revamp to remove confusion by some end users
  * Update backlash value from driver as it arrives
  * Fix toggle of meridian flip unit
  * Fix gain behavior setting in focus module. It should use value
    stored in config unless changed by user
  * Add support for direct gain setting in capture module
  * Fallback to default configs in case dns lookup fails for .local
    addresses
  * Bugfix for focus looping with HFR setup
  * Sample the fits viewer's histogram calculation
  * Make the meridian flip hour angle unit to be in degrees by
    default since this is a common settings used by many mounts
  * Remove debug that was added by mistake
  * Flip correction vector for southern hemisphere
  * Set the exposure restart button as default since it was
    defaulting to record which should not be the case
  * Add support to setting backlash directly in Ekos focus module
    IF supported by the INDI driver (kde#410804)
  * Check against device name and not pointer when removing
  * Fix minor warning
  * remove unnecessary debug message
  * Adding support for debayer in video stream window
- New _constraints for ppc64/ppc64le to avoid "No space left on
  device" and "Out of memory" errors
* Thu Aug  8 2019 wbauer@tmo.at
- Update to 3.3.4
  * Use i18nc for Not Applicable
  * Clean up how group debug options are parsed
  * Rolloff roof handling introduced
  * Comment unused variable
  * use rangeHA to make sure -12 < HA <= 12
  * Proper disconnection of Dark Library signals and slots in
    various Ekos modules
  * Read astrometry config file on other platforms than OS X
  * Fix bug#410573 in addition to initial support for dust caps in
    Dark Library (kde#410573)
  * always evaluate statistics after opening regardless of
    histogram
  * Fix double/float conversion in Java code
  * Fix missing include in Android build
- Clean up spec file: remove conditionals for no longer supported
  distribution versions
* Mon Aug  5 2019 wbauer@tmo.at
- Update to 3.3.3
  * qMin --> qMax since we need rate 0 to 3
  * Fix proper disconnection for KSMessageBox signals
  * Another attempt at fixing odd behavior of accept and reject
    roles. Now using ActionRole and simply connecting the button
    click to the dialog accept and reject signals
  * Further improvements to the reliability of the system after a
    crashed driver is restarted
  * Add support to restarting crashed drivers for local servers
  * sizeInBytes is only available in Qt 5.10+, thanks to jpaana
    for the heads up
  * Send preview JPEGs when they are generated to the client
  * Migrate more KMessageBox --> KSMessageBox
  * Try to solve Qt warning about adding to existing layout
  * Bug fix paused during dithering not resuming
  * Fix minor warning
  * Migrate dark library to async KSMessageBox
  * Remove rest of autonomous option that was deleted
  * remove & when comparing button texts
  * Removing unnecessary autonomous option for dialog with the
    introduction of the new KSMessageBox class that open message
    box asynchronous and can be programmatically activated with a
    timer
  * Fix crash in downloadJob due to possible using raw pointer
    before
  * Add new KSMessageBox class to fulfill some KStars specific
    requirements
  * Add helpful comments
  * Autofocus disturbing meridian flip corrected
  * Show the tracking box on the inital focusing frame
  * refactor isSlewDirty and set it as false in cases of IDLE and
    ALERT states for EqNP (kde#410094)
  * Check for refocus also during the calibration stage
  * Add support to CONFIG_PURGE and add more options to clear some
    mount data in case of trouble
  * Add more protection boundary checks
  * remove unnecessary cast
  * Reset autofocus when executing a job, so that focus step is
    applied properly when checked
  * Fix regression for non-guide dithering and re-arrange guide
    option to make dither frequency has its own row
  * Add option to control auto park post PAA tool operation
  * Introduce autonomousMode option to run KStars in autonomous
    mode whereas user interaction is not expected so popup dialogs
    are suppressed whenever possible. All KMessageBox calls are
    convereted to application to KSNotification calls
  * Fix translation issues with solar system objects
  * Precess sun to get correct accurate geocentric coordinates
  * When evaluating twilight restriction, shift dusk to next day
    when it happens before dawn on the same day
  * Display more information about version and interface once
    device is online
  * Fix non-static warning
  * Only construct histogram synchronously when required
  * Explicitly use setCurrentIndex since setCurrentText is
    problematic
  * Motion control for domes added
* Wed Jul  3 2019 wbauer@tmo.at
- Update to 3.3.2
  * http://knro.blogspot.com/2019/06/kstars-v331-is-released.html
  * New Ekos Observatory Module
  * Meridian Flip moved from the Capture Module to the Mount Module
  * FPS control in the Stream window is replaced by Frame Duration
    in seconds control
  * Reset focus frame when mount slews
  * Do not abort PHD2 guiding while suspended
  * Check if dust cap is detected before checking whether the
    camera is shutterful or shutterless
  * Fix translation issue with Sun, Moon, and Earth designations
* Fri May 31 2019 wbauer@tmo.at
- Update to 3.2.3
  * http://knro.blogspot.com/2019/05/kstars-v323-is-released.html
  * The Sky Map cursor can now be configured
  * New option to make left click immediately snap to the object
    under the cursor
  * Include the profile name directly into the Window title for
    Ekos
  * A few icon changes in Ekos
  * Fixed a race condition when using a guide camera (kde#407952)
  * Improved the estimated time of scheduler jobs where there are
    repeated jobs in the sequence
* Sun May 12 2019 wbauer@tmo.at
- Update to 3.2.2
  * http://knro.blogspot.com/2019/05/kstars-v322-is-released.html
  * Important stability fix for crashes reported with FITS Viewer
  * Ignore Video Streaming when guiding via PHD2 with a video
    device
  * Automatic syncing for Active Devices on Startup
  * Meridian Flip Fixes
  * Keep GUI parameters for scheduler and capture in sync with row
    selection
  * When a manual filter is detected, prompt user to change the
    filter and update the driver accordingly
  * Fix observing list wizard object filter by time and altitude
    and introduce a coverage param where the user can control the
    percentage
  * Improved saving of settings in all Ekos modules
* Thu Apr 25 2019 wbauer@tmo.at
- Update to 3.2.1
  * expand bsd license in cmake modules
  * Saving after reordering jobs enabled
  * Fix minor typo
  * Refactor and simplify guide settings and init
  * Simplify some default settings
  * Focus settings complete
  * More work on refactor settings
  * Use qCWarning
  * Bug fix for calculating required light frames
* Tue Apr 16 2019 wbauer@tmo.at
- Update to 3.2.0
  * Capture counting corrected
  * Do not connect to EkosLive with empty username
  * Also accept .fits.fz in FITSViewer
  * Fix slew and sync in KStars Lite
  * Clean module registration
  * Use click to trigger the change since the signals are attached
    to the button clicked event
  * Show toolip explicitly on button click
  * Add information icon to explain what the guiding rate control
    is for
  * Resume KStars if paused in EkosLive
  * Make sure clock is ticking and sync with system time when
    websocket connection is established
  * Move auto star selection for calibration to main guide module
    to make it more accessible
  * Fix issue with online solver args
  * Add RC telescope type
  * Fix capture delay when using legacy polar alignment tool
  * If primary or guide IDs are zero or less, set profile scope to
    Default
  * Add support to updating scopes and profiles
  * Scope commands do not require active connection
  * GET_SCOPES can now be sent before Ekos is online
  * Add scope websocket functions to add and delete scopes.
    Improve getScopes to cover all available telescopes
  * Send profile when deleting or adding one
  * Unchecking the meridian flip checkbox reset the meridian flip
    state
  * Do not change filter directly, use the filter manager
  * Fix infobox setting not sticking for some reason under Qt 5.12
  * Save focus module filter wheel and filter in options
  * Fix altitude restriction log and allow restriction down to -15
    degrees
  * Wait until backlash builds up before moving to more aggressive
    pulses that might cause overshooting the target position
  * Add debug log for remaining angle for mount rotation in
    alignment module
  * Add websocket function to get all drivers
  * Update docs
  * Profile management via websocket is ready for testing
  * Initial work for profile and driver exposure to ekoslive
  * Bugfix: proper usage of abort() for finishing a capture
    sequence queue
  * Reduce calibration iterations to 3 by default as it is mostly
    what is required for most cases
  * Prevent rescheduling aborted jobs until all jobs are processed
  * Make Scheduler robust against guiding problems
  * Keep meridian flip in capture and mount in sync (kde#405325)
  * Fix websocket getting called from a different thread
  * Add EkosLive DBus methods and properties
  * Display saved DSLR infos
  * Making the StarProfile Viewer fix from 3.1.0 work for Guide
    and Focus Views too
  * Load captured RAW images in summary without have to
    double-covert them since they are converted once in INDI::CCD
  * Only remove .fits explicitly from base name instead of finding
    last decimal point since this causes conflicts with exposures
    in file names
  * Make the mount window resizable to fit on different DPIs
* Mon Mar 11 2019 wbauer@tmo.at
- Update to 3.1.1
  * Comment out obsolete slot connect
  * Remove unrequired attributes (kde#405188)
  * Notify user of error in focusing even when not in autofocus
  * Add support to sending horizontal coordinates from the mount
    box
  * Improve behavior for dark and flat frames capture when it comes
    to covering the mount
  * Support converting images to FITS
  * Before loading next image, check if current image is temporary
    and if yes remove it from disk
  * Add notification dialog for user to cover scope with flat field
    light source in case of manual source
  * Making the initial astrometry.net path change automatic
  * More PHD2 fixes
  * Add comet and asteroid orbital elements auto update on startup
  * Make selection behavior single rows for the capture jobs
  * Deleting arbitrary imaging sequence in the Capture module
    corrected
  * Fix upload issues to the cloud with compressed images
  * Fix state of ekoslive button toggle on startup
  * fitsviewer: Do not exit program on error, return error code
* Wed Feb 27 2019 wbauer@tmo.at
- Update to 3.1.0
  * http://knro.blogspot.com/2019/02/kstars-v310-is-released.html
  * Fixed a few bugs with the Ekos Scheduler along with making
    steady improvements to cover all corner cases for multi-object
    multi-night scheduling which can become quite complex
  * Added a new feature to the Focus module: Ring-field focusing
  * Migrated the Meridian Flip handling code to the Ekos Mount tab
  * Migrated online Ekos documentation to KStars official
    documentation
  * Introduced manual workflow for users who would like to use Ekos
    Polar Alignment Assistant Tool with manual non-GOTO mounts
  * The LiveView window received a few enhancement to enable
    zooming and panning for supported DSLR cameras
  * The FITS Viewer window is now automatically raised to the
    foreground when a new image arrives
  * Dark Library now considers all DSLRs to be shutterless
  * Mounts are grouped by manufacturer in the Equipment Profile
    Editor
  * Preliminary support for websocket to INDI::CCD on the client
    side
  * DBus interface expansion to provide more fine control over
    KStars
  * Fixed relative focuser bug in autofocus mode
  * Improved multi-channel histogram by providing dedicated controls
    to each channel
  * Fixed Auto-Stretch affecting raw image values
  * Support for compressed FITS (*.fits.fz) in INDI. This can cut
    the transmission time to 30%%!
  * Improved display of Parked status
  * KStars defaults to limited resource mode on ARM architecture
  * When there is binning change, always FORCE setting of frame
    values even if they did not change
- Add "AND GPL-3.0-or-later" to the license, a few source files
  require that
* Thu Dec 20 2018 wbauer@tmo.at
- Update to 3.0.0
  * http://knro.blogspot.com/2018/12/kstars-v300-is-released.html
  * New XPlanet Solar System Viewer
  * Improved FITS Viewer GUI
  * Ekos scheduler improvements
  * Improvements to Scripting & DBus support
  * Lunar Eclipses: added functionality to calculate and draw the
    earth's shadow disk on the Moon from any distance. There is a
    new eclipse tool in the astrocalc which can find lunar eclipses
    quite fast.
  * Find Dialog is now persistent so it remembers the past searches
  * The capture module now incorporates a cooler On/Off button.
    Additionally, user can now clear Camera configuration.
  * Dedicated Binary Object channels when communicate with INDI
    driver to increase throughput and responsiveness of drivers
  * Fixed performance regression in Star Profile viewer
  * Guide mode resets calibration when it detects pier side
    changing
  * Migrating code to new style Qt Signal/Slot connections
  * J2000/JNow support in Mount Module
  * Do not cast DSO coords seconds to int as we lose important
    precision. Use full resolution as double.
  * Fix issue with subframed calibration when auto-select star is
    not enabled. Now subframed star position is set properly in the
    internal guider before.
  * Support for compressed FITS files (.fits.gz)
  * Add live view support to focus module and rework existing one
    in capture to be icon based
  * Show loaded coords in sexigesimal format and in high precision
    when possible
  * Do not add any camera or ST4 devices to guide module if guider
    is external. Instead put guider type in guider dropdown and
    disable it.
  * Honor settling time in Polar Alignment Assistant tool
  * Add warning when slewing to Sun. Adjust tracking rate if
    supported by the mount depending on the object type.
  * Add option to control DSLR image viewer. It can now be turned
    off.
  * Improve PHD2 support
- Drop disable_downloading_into_system_dirs.patch, the kauth helper
  that writes files to system dirs has been disabled upstream
  because of reliability problems
* Mon Aug 20 2018 wbauer@tmo.at
- Update to 2.9.8
  * http://knro.blogspot.com/2018/08/kstars-298-released.html
  * Fixed several issues in the Ekos scheduler to enable running
    duplicate jobs
  * Fixed many problematic i18n strings that accumulated over the
    years
  * Improved KStars Lite android build process and fixed touch
    support
  * Fixed several issues with Ekos PHD2 support
  * Fixed logging out in capture module
  * Fixed minor EBN issues
  * Using Max RMS value as the threshold to abort the guider
    instead of maximum pulse length
* Fri Jul 27 2018 jengelh@inai.de
- Trim redundancies from the description again.
* Thu Jul 26 2018 wbauer@tmo.at
- Update to 2.9.7
  * http://knro.blogspot.com/2018/07/kstars-v297-is-released.html
  * The Ekos scheduler's behavior has been improved under a number
    of scenarios
  * The Polar Alignment Assistant tool received few improvements to
    simplify the process, it's now literally a 1-button click
    operation
  * Support for EkosLive is added in this release
  * KStars now offers an easy method to add INDI custom drivers
  * Support for loading compressed FITS (*.fits.gz) in FITS Viewer
  * Android fixes + improvements by GSoC 2018 student Csaba
  * Disabled internet check for online astrometry solver to
    workaround Qt bug
  * Fixed PHD2 file not found issue
  * Added option to restart alignment process in scheduler in case
    of calibration failure
  * Support for manual dither plus dithering to a specific X,Y
    location
  * Support for Auto Park Timer in Mount Module
  * Support for Remote Drivers in the Profile Editor
  * Added video exposure duration control to the Video Stream
    window
- Rebase disable_downloading_into_system_dirs.patch
- Update build requirements
- Build with gcc7 on Leap 42.3, it doesn't compile with 4.8 anymore
- Update package description
* Mon Jul  9 2018 wbauer@tmo.at
- Update to 2.9.6
  * http://knro.blogspot.com/2018/05/kstars-296-is-released.html
  * Fixed long-standing bug where Time zone was not updated
    correctly from INDI GPS
  * Fixed Filter Manager settings as it was not updating the
    database properly
  * Fixed centering & tracking of empty sky
  * Fixed Polar Alignment Assistant rotation in the southern
    hemisphere
  * Added a method to clear DSLR info in case they were entered
    incorrectly
  * Added J2000 support in the Mount Control panel in addition to
    the standard JNow
  * Alignment FOV is now always editable
  * CCD Capture format and directory are now persistent
  * Guiding is aborted when mount is slewing or parking
  * Clang fixes by Csaba Kertesz as part of GSoC 2018
- Drop Fix-build-with-Qt-511.patch, merged upstream
* Sun Jun  3 2018 christophe@krop.fr
- Add Fix-build-with-Qt-511.patch
- Run spec-cleaner
* Wed Apr 25 2018 wbauer@tmo.at
- Update to 2.9.5
  * http://knro.blogspot.co.at/2018/04/kstars-295-is-out.html
  * New experimental adaptive HFR Thresholding algorithm that
    selects the median HFR value filter-wise
  * Ekos Scheduler module has received major patches from Eric
    Dejouhanet to improve its reliability and fix some corner cases
  * A quite illusive and annoying time-zone related bug was fixed
    when using INDI GPS devices
  * Align module FOV now defaults to zero on startup
* Wed Apr 18 2018 wbauer@tmo.at
- Update to 2.9.4
  * http://knro.blogspot.co.at/2018/04/spring-season-kstars-v294-is-released.html
  * New highly efficient binary interface for asteroids that would
    allow quite large (> 100MB) and distant catalogs to be loaded
    into KStars without a major impact on performance
  * Automatic Flat field calculations were fixed for multi-channel
    DSLR frames along with an improved DSLR popup dialog
  * The Ekos scheduler workflow was revamped to evaluate all jobs
    every time a new job is invoked to ensure all scores are
    updated accordingly and not only on the first job run
  * More SEP work for star & galaxy detection is merged into the
    internal guide module resulting in a better object detection
    even in noisy environments
  * The guide module is now a lot more tolerant to passing clouds
  * Users can now instruct Ekos to take flat field frames exactly
    at the same focus position where light frames of the same
    filter were captured
  * FITS handling code was optimized with loading times improving
    on the order of 300%%
- Mark license files as %%license instead of %%doc
* Sat Mar  3 2018 wbauer@tmo.at
- Update to 2.9.3
  * http://knro.blogspot.co.at/2018/02/kstars-293-is-out-with-numerous-fixes.html
  * several important fixes, mostly in Ekos scheduler and capture
    modules
* Mon Jan 29 2018 wbauer@tmo.at
- Update to 2.9.2
  * http://knro.blogspot.co.at/2018/01/kstars-292-released.html
  * New theming support
  * Add the found stars to the Zoom Menu
  * Add Mount Control Panel access to the telescope tool bar
  * Add support to Sensor FOV that can be triggered from the Ekos
    tool bar, Color can be set from color scheme
  * Use Human counting in the Star Profile Viewer
  * Nicer icons for the Star Profile Viewer
  * Only apply PA calculation on square FOVs
  * Adding experimental support for differential slewing in align
    module
  * Sync INDI drivers list
  * Remove completed jobs from sorted jobs
  * Display local meridian even if grids are off or in equatorial
    mode (kde#389289)
  * Add option to skip sorting jobs and run them as-is in the order
    they are added
  * Reset to correct page in wizard
  * Remove Breeze icons and relying on install theme. Changing some
    icon to look better with the default KStars theme
  * Add logging when saving FITS to disk
  * Update appstream screenshots
  * band-aid fix for cursor bug in FITS View
- Drop upstreamed fix-build-with-gcc48.patch
* Sat Jan 20 2018 wbauer@tmo.at
- Update to 2.9.1
  * http://knro.blogspot.co.at/2018/01/kstars-291-is-off-to-fantastic-start-in.html
  * Easier to set Park Position
  * Additional PHD 2 Support
  * Drift Graphics Updates
  * New 3D Star Profile and Data Visualization Tool
  * Bugfixes and other improvements
- Add fix-build-with-gcc48.patch to make it build with gcc 4.8 on
  Leap 42
- Build with Qt5DataVisualization (new in Qt 5.7) on Tumbleweed and
  Leap 15 to enable the new "3D Star Profile and Data Visualization
  Tool"
* Wed Dec 20 2017 wbauer@tmo.at
- Update to 2.8.9
  * kstars is released independently from KDE Applications now
  * Lots of changes since 2.7.10 that was shipped with KDE Applications
    17.08.3, please see http://knro.blogspot.co.at/ or the
    included ChangeLog file (in /usr/share/doc/packages/kstars/)
    for details
* Thu Nov  9 2017 lbeltrame@kde.org
- Update to 17.08.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.08.3.php
- Changes since 17.08.2:
  * None
* Mon Oct 16 2017 lbeltrame@kde.org
- Update to 17.08.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.08.2.php
- Changes since 17.08.1:
  * None
* Thu Sep  7 2017 lbeltrame@kde.org
- Update to 17.08.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.08.1.php
- Changes since 17.08.0:
  * None
* Fri Aug 11 2017 christophe@krop.fr
- Update to KDE Applications 17.08.0
  * New feature release
  * https://www.kde.org/announcements/announce-applications-17.08.0.php
- Changes since 17.04.3 :
- Too many changes to list here
* Sat Aug  5 2017 christophe@krop.fr
- Update to KDE Applications 17.07.90
  * KDE Applications 17.07.90
  * https://www.kde.org/announcements/announce-applications-17.07.90.php
- Add disable_downloading_into_system_dirs.patch. Saving runtime files into
  system directories is not allowed.
* Sat Jul 15 2017 lbeltrame@kde.org
- Update to 17.04.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04.3.php
- Changes since 17.04.2:
  * None
* Wed Jun  7 2017 lbeltrame@kde.org
- Update to 17.04.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04.2.php
- Changes since 17.04.1:
  * None
* Wed May 17 2017 lbeltrame@kde.org
- Update to 17.04.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04.1.php
- Changes since 17.04.0:
  * None
* Mon May  1 2017 wbauer@tmo.at
- Add libnova-devel and gsl-devel build requirements, necessary
  when building with libindi now
* Sun Apr 16 2017 lbeltrame@kde.org
- Update to 17.04.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04.0.php
- Changes since 17.03.90:
  * None
* Wed Apr 12 2017 lbeltrame@kde.org
- Update to 17.03.90
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04-rc.php
- Changes since 17.03.80:
  * None
* Sat Mar 25 2017 lbeltrame@kde.org
- Update to 17.03.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.03.80.php
- Changes since 16.12.3:
  * Too many changes to list here
* Thu Mar  9 2017 lbeltrame@kde.org
- Update to 16.12.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-16.12.3.php
- Changes since 16.12.2:
  * None
* Sat Feb 25 2017 asterios.dramis@gmail.com
- Enable wcslib-devel build requirement also for Leap >= 42.3.
* Thu Feb  9 2017 lbeltrame@kde.org
- Update to KDE Applications 16.12.2
  * KDE Applications 16.12.2
  * https://www.kde.org/announcements/announce-applications-16.12.2.php
* Sat Jan 14 2017 lbeltrame@kde.org
- - Update to KDE Applications 16.12.1
  * KDE Applications 16.12.1
  * https://www.kde.org/announcements/announce-applications-16.12.1.php
* Tue Dec 13 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.12.0
  * KDE Applications 16.12.0
  * https://www.kde.org/announcements/announce-applications-16.12.0.php
* Wed Dec  7 2016 asterios.dramis@gmail.com
- Added new build requirement libraw-devel.
- Added new build requirement wcslib-devel for openSUSE Tumbleweed.
- Renamed libeigen3-devel build requirement to eigen3-devel.
- Removed libcfitsio-devel build requirement (already included as
  cfitsio-devel).
* Sat Dec  3 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.11.90
  * KDE Applications 16.12.0 RC
  * https://www.kde.org/announcements/announce-applications-16.12-rc.php
* Tue Nov 29 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.11.80
  * KDE Applications 16.12.0 Beta
  * https://www.kde.org/announcements/announce-applications-16.12-beta.php
* Wed Nov  9 2016 lbeltrame@kde.org
- Update to KDE Applications 16.08.3
  * KDE Applications 16.08.3
  * https://www.kde.org/announcements/announce-applications-16.08.3.php
* Tue Oct 11 2016 lbeltrame@kde.org
- KDE Applications 16.08.2
  https://www.kde.org/announcements/announce-applications-16.08.2.php
* Fri Sep  9 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.08.1
  * KDE Applications 16.08.1
  * https://www.kde.org/announcements/announce-applications-16.08.1.php
* Fri Aug 12 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.08.0
  * KDE Applications 16.08.0
  * https://www.kde.org/announcements/announce-applications-16.08.0.php
* Tue Aug  9 2016 wbauer@tmo.at
- Cleanup build requirements
* Mon Aug  8 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.07.90
  * KDE Applications 16.07.90 (16.08-RC)
  * https://www.kde.org/announcements/announce-applications-16.07.90.php
* Fri Jul  8 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.04.3
  * KDE Applications 16.04.3
  * https://www.kde.org/announcements/announce-applications-16.04.3.php
* Fri Jun 10 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.04.2
  * KDE Applications 16.04.2
  * https://www.kde.org/announcements/announce-applications-16.04.2.php
* Sat May  7 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.04.1
  * KDE Applications 16.04.1
  * https://www.kde.org/announcements/announce-applications-16.04.1.php
* Sun Apr 17 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.04.0
  * KDE Applications 16.04.0
  * https://www.kde.org/announcements/announce-applications-16.04.0.php
* Mon Apr 11 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.03.90
  * KDE Applications 16.04.0 RC
  * https://www.kde.org/announcements/announce-applications-16.04-rc.php
* Sun Mar 13 2016 tittiatcoke@gmail.com
- Update to KDE Applications 15.12.3
  * KDE Applications 15.12.3
  * https://www.kde.org/announcements/announce-applications-15.12.3.php
  * boo#970855
* Sat Feb 13 2016 tittiatcoke@gmail.com
- Update to KDE Applications 15.12.2
  * KDE Applications 15.12.2
  * https://www.kde.org/announcements/announce-applications-15.12.2.php
  * boo#966605
* Sat Jan  9 2016 tittiatcoke@gmail.com
- Update to KDE Applications 15.12.1
  * KDE Applications 15.12.1
  * https://www.kde.org/announcements/announce-applications-15.12.1.php
  * boo#961265
* Sun Dec 13 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.12.0
  * KDE Applications 15.12.0
  * https://www.kde.org/announcements/announce-applications-15.12.0.php
  * boo#958887
* Tue Nov 10 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.08.3
  * KDE Applications 15.08.3
  * https://www.kde.org/announcements/announce-applications-15.08.3.php
  * boo#954531
* Sun Oct 11 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.08.2
  * KDE Applications 15.08.2
  * https://www.kde.org/announcements/announce-applications-15.08.2.php
* Mon Oct  5 2015 wbauer@tmo.at
- Own directory %%_datadir/appdata to fix build on Leap
* Sun Sep 13 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.08.1
  * KDE Applications 15.08.1
  * https://www.kde.org/announcements/announce-applications-15.08.1.php
* Wed Aug 19 2015 cgiboudeaux@gmx.com
- Update to KDE Applications 15.08.0
  * KDE Applications 15.08.0
  * https://www.kde.org/announcements/announce-applications-15.08.0.php
* Fri Aug  7 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.07.90
  * KDE Applications 15.08.0 RC1
  * https://www.kde.org/announcements/announce-applications-15.07.90.php
* Mon Jul  6 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.04.3
  * KDE Applications 15.04.3
  * https://www.kde.org/announcements/announce-applications-15.04.3.php
* Sat May 30 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.04.2
  * KDE Applications 15.04.2
  * https://www.kde.org/announcements/announce-applications-15.04.2.php
* Mon May 11 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.04.1
  * KDE Applications 15.04.1
  * https://www.kde.org/announcements/announce-applications-15.04.1.php
* Sat Apr 11 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.04.0
  * KDE Applications 15.04.0
  * https://www.kde.org/announcements/announce-applications-15.04.0.php
* Sat Mar 21 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.03.95
  * KDE Applications 15.04 RC
* Sun Mar  8 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.03.80
  * KDE Applications 15.04 Beta
* Tue Mar  3 2015 tittiatcoke@gmail.com
- Update to KDE Applications 14.12.3
  * KDE Applications 14.12.3
  * See https://www.kde.org/announcements/announce-applications-14.12.3.php
* Sun Feb  1 2015 tittiatcoke@gmail.com
- Update to KDE Applications 14.12.2
  * KDE Applications 14.12.2
  * See https://www.kde.org/announcements/announce-applications-14.12.2.php
* Mon Jan 12 2015 tittiatcoke@gmail.com
- Update to KDE Applications 14.12.1
  * KDE Applications 14.12.1
  * See https://www.kde.org/announcements/announce-applications-14.12.1.php
* Wed Dec 17 2014 tittiatcoke@gmail.com
- Update to KDE Applications 14.12.0
  * KDE Applications 14.12.0
  * See https://www.kde.org/announcements/announce-applications-14.12.0.php
* Sun Nov  9 2014 tittiatcoke@gmail.com
- Update to 4.14.3
  * KDE 4.14.3 SC Bugfix Release
  * See http://www.kde.org/announcements/announce-4.14.3.php
* Sun Oct 12 2014 tittiatcoke@gmail.com
- Update to 4.14.2
  * KDE 4.14.2 SC Bugfix Release
  * See http://www.kde.org/announcements/announce-4.14.2.php
* Sat Sep 13 2014 tittiatcoke@gmail.com
- Update to 4.14.1
  * KDE 4.14.1 SC Bugfix Release
  * See http://www.kde.org/announcements/announce-4.14.1.php
* Fri Aug 15 2014 tittiatcoke@gmail.com
- Update to 4.14.0
  * KDE 4.14.0 SC Final Release
  * See http://www.kde.org/announcements/4.14/
* Thu Jul 17 2014 cgiboudeaux@gmx.com
- Update to 4.13.90
  * KDE 4.14 Beta 2 release
  * See http://www.kde.org/announcements/announce-4.14-beta2.php
* Thu Jul 10 2014 cgiboudeaux@gmx.com
- Update to 4.13.80
  * KDE 4.14 Beta 1 release
  * See http://www.kde.org/announcements/announce-4.14-beta1.php
* Sun Jun  8 2014 tittiatcoke@gmail.com
- Update to 4.13.2
  * KDE 4.13  release
  * See http://www.kde.org/announcements/announce-4.13.2.php
* Fri May  9 2014 tittiatcoke@gmail.com
- Update to 4.13.1
  * KDE 4.13.1  bug fix release
  * See http://www.kde.org/announcements/announce-4.13.1.php
* Sun May  4 2014 hrvoje.senjan@gmail.com
- Added libqjson-devel BuildRequires: enables KStars to utilize
  online web services to perform astrometric solving for images in
  Ekos alignment module
* Fri Apr 11 2014 tittiatcoke@gmail.com
- Update to 4.13.0
  * KDE 4.13  release
  * See http://www.kde.org/announcements/4.13/
* Thu Mar 27 2014 tittiatcoke@gmail.com
- Update to 4.12.97
  * KDE 4.13 RC  release
  * See http://www.kde.org/announcements/announce-4.13-rc.php
* Thu Mar 20 2014 tittiatcoke@gmail.com
- Update to 4.12.95
  * KDE 4.13 Beta 3  release
  * See http://www.kde.org/announcements/announce-4.13-beta3.php
* Thu Mar 13 2014 tittiatcoke@gmail.com
- Update to 4.12.90
  * KDE 4.13 Beta 2  release
  * See http://www.kde.org/announcements/announce-4.13-beta2.php
* Fri Mar  7 2014 tittiatcoke@gmail.com
- Update to 4.12.80
  * KDE 4.13 Beta 1  release
  * See http://www.kde.org/announcements/announce-4.13-beta1.php
* Sat Feb  1 2014 tittiatcoke@gmail.com
- Update to 4.12.2
  * KDE 4.12.2  release
  * See http://www.kde.org/announcements/announce-4.12.2.php
* Sat Jan 11 2014 tittiatcoke@gmail.com
- Update to 4.12.1
  * KDE 4.12.1  release
  * See http://www.kde.org/announcements/announce-4.12.1.php
* Sat Dec 14 2013 tittiatcoke@gmail.com
- Update to 4.12.0
  * KDE 4.12.0  release
  * See http://www.kde.org/announcements/4.12.php
* Fri Nov 29 2013 tittiatcoke@gmail.com
- Update to 4.11.97
  * KDE 4.12 RC 1 release
  * See http://www.kde.org/announcements/announce-4.12-rc.php
* Sat Nov 23 2013 tittiatcoke@gmail.com
- Update to 4.11.95
  * KDE 4.12 Beta 3 release
  * See http://www.kde.org/announcements/announce-4.12-beta3.php
* Sat Nov 16 2013 tittiatcoke@gmail.com
- Update to 4.11.90
  * KDE 4.12 Beta 2 release
  * See http://www.kde.org/announcements/announce-4.12-beta2.php
* Sat Nov  9 2013 tittiatcoke@gmail.com
- Update to 4.11.80
  * KDE 4.12 Beta 1 release
  * See http://www.kde.org/announcements/announce-4.12-beta1.php
* Sat Nov  2 2013 tittiatcoke@gmail.com
- Update to 4.11.3
  * KDE 4.11.3 bugfix release
  * See http://www.kde.org/announcements/announce-4.11.3.php
* Sat Sep 28 2013 tittiatcoke@gmail.com
- Update to 4.11.2
  * KDE 4.11.2 bugfix release
  * See http://www.kde.org/announcements/announce-4.11.2.php
* Sun Sep  1 2013 tittiatcoke@gmail.com
- Update to 4.11.1
  * KDE 4.11.1 bugfix release
  * See http://www.kde.org/announcements/announce-4.11.1.php
* Thu Aug  8 2013 tittiatcoke@gmail.com
- Update to 4.11.0
  * KDE 4.11 Final release
  * See http://www.kde.org/announcements/4.11/
* Thu Jul 25 2013 hrvoje.senjan@gmail.com
- Update to 4.10.97
  * KDE 4.11 RC 2 release
  * See http://www.kde.org/announcements/announce-4.11-rc2.php
* Mon Jul 15 2013 cgiboudeaux@gmx.com
- Update to 4.10.95
  * KDE 4.11 RC 1 release
  * See http://www.kde.org/announcements/announce-4.11-rc1.php
* Thu Jun 27 2013 tittiatcoke@gmail.com
- Update to 4.10.90
  * KDE 4.11 Beta 1 release
  * See http://www.kde.org/announcements/announce-4.11-beta2.php
* Thu Jun 13 2013 tittiatcoke@gmail.com
- Update to 4.10.80
  * KDE 4.11 Beta 1 release
  * See http://www.kde.org/announcements/announce-4.11-beta1.php
* Sat Jun  1 2013 tittiatcoke@gmail.com
- Update to 4.10.4
  * Bugfix release
  * See http://www.kde.org/announcements/announce-4.10.4.php
  * resolves bnc#8122760
* Sat May  4 2013 tittiatcoke@gmail.com
- Update to 4.10.3
  * Bugfix release
  * See http://www.kde.org/announcements/announce-4.10.3.php
  * resolves bnc#818500
* Mon Apr  1 2013 tittiatcoke@gmail.com
- Update to 4.10.2 \n  * Bugfixes
* Sat Mar  2 2013 tittiatcoke@gmail.com
- Update to 4.10.1
  * Contains bug fixes. See http://www.kde.org/announcements/
  for more information
* Thu Jan 31 2013 tittiatcoke@gmail.com
- Update to 4.10.0
  * This is the final release for 4.10. Contains bugfixes
* Thu Jan 17 2013 tittiatcoke@gmail.com
- Update to 4.9.98
  * This is the third RC release for 4.10. Contains bugfixes
* Thu Jan  3 2013 tittiatcoke@gmail.com
- Update to 4.9.97
  * This is the second RC release for 4.10. Contains bugfixes
* Wed Dec 19 2012 tittiatcoke@gmail.com
- Update to 4.9.95
  * This is the first RC release for 4.10. Contains bugfixes
* Sat Dec  1 2012 tittiatcoke@gmail.com
- Update to 4.9.90
  * This is the second Beta release for 4.10. Contains bugfixes
* Sat Nov 24 2012 tittiatcoke@gmail.com
- Update to 4.9.80
  * See http://www.kde.org/announcements/announce-4.10-beta1.php
* Fri Nov  2 2012 tittiatcoke@gmail.com
- Update to 4.9.3
  * see http://kde.org/announcements/announce-4.9.3.php for details
* Sat Sep 29 2012 tittiatcoke@gmail.com
- Update to 4.9.2
  * see http://kde.org/announcements/announce-4.9.2.php for details
* Wed Sep  5 2012 dmueller@suse.com
- update to 4.9.1
  * see http://kde.org/announcements/4.9.1/ for details
* Mon Jul 30 2012 dmueller@suse.com
- update to 4.8.5
  * see http://kde.org/announcements/changelogs/changelog4_8_4to4_8_5.php for details
- remove upstreamed patch
* Mon Jul 30 2012 aj@suse.de
- Fix build with glibc 2.16 (TIME_UTC is a macro).
* Fri Jun  1 2012 dmueller@suse.com
- update to 4.8.4
  * see http://kde.org/announcements/changelogs/changelog4_8_3to4_8_4.php for details
* Thu May 24 2012 asterios.dramis@gmail.com
- Removed FindCFitsio.cmake.patch (not needed anymore after the update of the
  cfitsio package and the cfitsio.pc fix to correctly find the library).
- Removed libSatLib4 subpackage entry (which was disabled anyway) since it has
  been removed from the kstars package.
* Sun Apr 29 2012 dmueller@suse.com
- update to 4.8.3
  * see http://kde.org/announcements/changelogs/changelog4_8_2to4_8_3.php for details
* Sat Mar 31 2012 wstephenson@suse.com
- Add xz to BuildRequires
* Thu Mar 29 2012 dmueller@suse.de
- update to 4.8.2
  * see http://kde.org/announcements/changelogs/changelog4_8_1to4_8_2.php for details
* Fri Mar  2 2012 dmueller@suse.de
- update to 4.8.1
  * see http://kde.org/announcements/changelogs/changelog4_8_0to4_8_1.php for details
* Wed Jan 18 2012 dmueller@suse.de
- update to 4.8.0
  * first stable release of KDE 4.8 (only critical fixes over 4.7.98)
  * see http://kde.org/announcements/4.8/ for details
* Tue Jan 10 2012 dmueller@suse.de
- update to 4.7.98
  * RC2+ milestone release of KDE 4.8
  * see http://kde.org/announcements/4.8/ for details
* Wed Dec  7 2011 coolo@suse.com
- fix license to be in spdx.org format
* Fri Dec  2 2011 dmueller@suse.de
- update to 4.7.4
  * see http://kde.org/announcements/changelogs/changelog4_7_3to4_7_4.php for details
* Wed Nov  2 2011 dmueller@suse.de
- update to 4.7.3
  * see http://kde.org/announcements/changelogs/changelog4_7_2to4_7_3.php for details
* Sun Oct  2 2011 dmueller@suse.de
- update to 4.7.2
  * see http://kde.org/announcements/changelogs/changelog4_7_1to4_7_2.php for details
* Thu Sep 22 2011 asterios.dramis@gmail.com
- Added a patch for FindCFitsio.cmake to correctly find the cfitsio library.
* Tue Sep 20 2011 asterios.dramis@gmail.com
- Spec file updates:
  * Changed License: to GPL-2.0+.
  * Cleanup in BuildRequires: (removed depedencies left from the kdeedu package
    and added Mesa-devel, libindi, libkde4-devel and update-desktop-files).
  * Removed libkeduvocdocument4 from Requires: and %%py_requires (not needed).
  * Recommend libindi and xplanet.
  * Don't install the static library (libhtmesh.a).
  * Changed the Group: of libSatLib4 to System/Libraries.
  * Removed /sbin/ldconfig %%post/%%postun sections for the main package (not
    needed).
  * Minor other updates.
* Wed Sep  7 2011 toddrme2178@gmail.com
- Added xplanet buildrequires
- Removed tests for obsolete openSUSE versions
  (fix for RPMLINT warning)
- Removed redundant buildrequires
- Cleaned up spec file formatting
* Thu Sep  1 2011 dmueller@suse.de
- update to 4.7.1
  * Bugfixes over KDE 4.7.0
  * see http://kde.org/announcements/changelogs/changelog4_7_0to4_7_1.php for details
* Fri Jul 22 2011 dmueller@suse.de
- update to 4.7.0
  * Small fixes over KDE 4.7 RC2
  * see http://kde.org/announcements/4.7 for details
* Sat Jul  9 2011 dmueller@suse.de
- update to 4.6.95
* Tue Jun 28 2011 dmueller@suse.de
- update to 4.6.90
* Fri May 20 2011 dmueller@suse.de
- update to 4.6.80
* Sun May  8 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110508
* Mon May  2 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110502
* Sat Apr 23 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110423
* Wed Apr 20 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110420
* Mon Apr 18 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110418
* Sun Apr 10 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110410
* Sun Apr 10 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110410
* Sat Apr  9 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110409
* Fri Apr  8 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110408
* Thu Apr  7 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110407
* Wed Apr  6 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110406
* Tue Apr  5 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110405
* Mon Apr  4 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110404
- Build based on standalone package in GIT
* Sun Apr  3 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110403
* Fri Apr  1 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110401
* Thu Mar 31 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110331
* Wed Mar 30 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110330
* Tue Mar 29 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110329
* Mon Mar 28 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110328
* Mon Mar 28 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110328
* Mon Mar 28 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110328
* Thu Mar 24 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110324
* Wed Mar 23 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110323
* Mon Mar 21 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110321
* Mon Mar 21 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110321
* Sat Mar 19 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110319
* Fri Mar 18 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110318
* Thu Mar 17 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110317
* Wed Mar 16 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110316
* Tue Mar 15 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110315
* Tue Mar 15 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110315
* Mon Mar 14 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110314
* Sun Mar 13 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110313
* Sat Mar 12 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110312
* Fri Mar 11 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110311
* Fri Mar 11 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110311
* Thu Mar 10 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110310
* Thu Mar 10 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110310
* Wed Mar  9 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110309
* Tue Mar  8 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110308
* Mon Mar  7 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110307
* Sun Mar  6 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110306
* Sat Mar  5 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110305
* Fri Mar  4 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110304
* Fri Mar  4 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110304
* Fri Mar  4 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110304
* Thu Mar  3 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110303
* Wed Mar  2 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110302
* Tue Mar  1 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110301
* Mon Feb 28 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110228
* Sun Feb 27 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110227
* Sun Feb 27 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110227
* Sat Feb 26 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110226
* Fri Feb 25 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110225
* Thu Feb 24 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110224
* Tue Feb 22 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110222
* Tue Feb 22 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110222
* Sun Feb 20 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110220
* Sat Feb 19 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110219
* Fri Feb 18 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110218
* Thu Feb 17 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110217
* Wed Feb 16 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110217
* Wed Feb 16 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110216
* Tue Feb 15 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110216
* Tue Feb 15 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110215
* Mon Feb 14 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110214
* Sun Feb 13 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110213
* Sat Feb 12 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110212
* Sat Feb 12 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110212
* Thu Feb 10 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110210
* Wed Feb  9 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110209
* Wed Feb  9 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110209
* Mon Feb  7 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110207
* Sun Feb  6 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110206
* Sat Feb  5 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110205
* Fri Feb  4 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110204
* Thu Feb  3 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110203
* Wed Feb  2 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110202
* Tue Feb  1 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110201
* Mon Jan 31 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110131
* Sun Jan 30 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110130
* Sun Jan 30 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110130
* Tue Jan 25 2011 ro@suse.de
- split off cantor devel to silence some rpmlint warnings
* Mon Jan 24 2011 ro@suse.de
- fix filelist to fix build again
* Wed Jan  5 2011 dmueller@suse.de
- update to 4.6.41_20110106
* Sun Dec 19 2010 tittiatcoke@gmail.com
- Update to 4.5.86svn1207757
* Fri Dec 10 2010 dmueller@suse.de
- update to 4.5.86svn1205247
* Wed Dec  1 2010 dmueller@suse.de
- update to 4.5.82svn1202688
* Mon Nov 29 2010 tittiatcoke@gmail.com
- Update to 4.5.81svn1202101
* Sun Nov 28 2010 tittiatcoke@gmail.com
- Added patch to avoid building rocs on openSUSE 11.1 and 11.2
* Fri Nov 19 2010 dmueller@suse.de
- update to 4.5.80
  * KDE 4.6 Beta1
  * no upstream changelog available.
* Thu Oct 28 2010 dmueller@suse.de
- update to 4.5.3
  * see http://kde.org/announcements/changelogs/changelog4_5_2to4_5_3.php for details
* Thu Sep 30 2010 dmueller@suse.de
- update to 4.5.2
  * see http://kde.org/announcements/changelogs/changelog4_5_1to4_5_2.php for details
* Fri Aug 27 2010 dmueller@suse.de
- update to 4.5.1
  * see http://kde.org/announcements/changelogs/changelog4_5_0to4_5_1.php for details
* Thu Aug 19 2010 dmueller@suse.de
- correct parley description
* Thu Jul 29 2010 dmueller@suse.de
- update to 4.5.0
  * KDE 4.5.0 final (version bump over RC3)
* Fri Jul 23 2010 dmueller@suse.de
- update to 4.4.95
  * KDE 4.5 RC3 (not announced)
  * critical fixes for 4.5.0 release
* Fri Jul 16 2010 dmueller@suse.de
- update to 4.4.93svn1149349
* Wed Jul  7 2010 dmueller@suse.de
- update to 4.4.5
  * bugfixes over 4.4.4
  * see http://kde.org/announcements/changelogs/changelog4_4_4to4_4_5.php for details
* Fri Jun 18 2010 dmueller@suse.de
- update to 4.4.4
  * bugfixes over 4.4.3
  * see http://kde.org/announcements/changelogs/changelog4_4_3to4_4_ 4.php for details
  * for most modules only version number as a change (4_4_BRANCH.diff already contained the diff
* Mon May 17 2010 llunak@novell.com
- update 4_4_BRANCH.diff: various fixes, translation updates
* Thu Apr 29 2010 dmueller@suse.de
- update to 4.4.3
  * bugfixes over 4.4.2
  * see http://kde.org/announcements/changelogs/changelog4_4_2to4_4_3.php for details
* Fri Mar 26 2010 dmueller@suse.de
- update to 4.4.2
  * bugfixes over 4.4.1
  * see http://kde.org/announcements/changelogs/changelog4_4_1to4_4_2.php for details
* Fri Feb 26 2010 dmueller@suse.de
- update to 4.4.1
  * bugfixes over 4.4.0
  * see http://kde.org/announcements/changelogs/changelog4_4_0to4_4_1.php for details
* Thu Feb  4 2010 dmueller@suse.de
- update to 4.4.0
  * Critical bugfixes only over 4.3.98
  * see http://www.kde.org/announcements/4.4/ for general overview
* Sun Jan 31 2010 dmueller@suse.de
- update to 4.3.98
  * see http://www.kde.org/announcements/announce-4.4-rc3.php for details
* Wed Jan 20 2010 dmueller@suse.de
- update to 4.3.95
  * see http://www.kde.org/announcements/announce-4.4-rc2.php for details
* Sun Jan 10 2010 ro@suse.de
- rediff patches to apply without fuzz
* Wed Jan  6 2010 dmueller@suse.de
- update to 4.3.90
  * see http://www.kde.org/announcements/announce-4.4-rc1.php for details
* Fri Dec 18 2009 dmueller@suse.de
- update to 4.3.85
  * see http://www.kde.org/announcements/announce-4.4-beta2.php for details
* Tue Dec  8 2009 ro@suse.de
- remove ocaml buildrequires from noarch specfile (unused)
* Fri Dec  4 2009 dmueller@suse.de
- update to 4.3.80:
  * see http://techbase.kde.org/Schedules/KDE4/4.4_Feature_Plan
* Wed Nov 18 2009 ro@suse.de
- rediff desktop-files.diff for fuzz=0
* Mon Nov  2 2009 dmueller@suse.de
- update to 4.3.3
  * see http://kde.org/announcements/changelogs/changelog4_3_2to4_3_3.php for details
* Thu Sep 24 2009 beineri@opensuse.org
- update 4_3_BRANCH.diff: khangman fixes and translation updates
* Wed Sep 16 2009 coolo@novell.com
- branch update for improved translations
* Fri Aug 28 2009 dmueller@suse.de
- update to 4.3.1
  * see http://kde.org/announcements/changelogs/changelog4_3_0to4_3_1.php for details
* Wed Aug 26 2009 mls@suse.de
- make patch0 usage consistent
* Wed Jul 29 2009 dmueller@suse.de
- update to 4.3.0
  * see http://kde.org/announcements/4.3 for details
* Tue Jul 21 2009 dmueller@suse.de
- update to 4.2.98
* Thu Jul  9 2009 dmueller@suse.de
- update to 4.2.96
* Wed Jun 24 2009 dmueller@suse.de
- update to 4.2.95
* Sat Jun 20 2009 beineri@opensuse.org
- drop kde4 package prefixes
* Fri Jun 19 2009 beineri@opensuse.org
- update build requires of -noarch
* Wed Jun  3 2009 dmueller@suse.de
- update to 4.2.90
* Wed May 27 2009 dmueller@suse.de
- update to 4.2.88svn973768
* Tue May 19 2009 dmueller@suse.de
- update to 4.2.87svn969966
* Mon May 18 2009 dmueller@suse.de
- update to 4.2.86svn967995
* Thu May 14 2009 dmueller@suse.de
- update to 4.2.85 (KDE 4.3 Beta1)
* Tue May 12 2009 dmueller@suse.de
- fix dependencies
* Sat May  2 2009 beineri@opensuse.org
- fix kde4-khangman missing data (bnc#481119)
* Thu Apr 30 2009 dmueller@suse.de
- update to 4.2.3
  * see http://kde.org/announcements/changelogs/changelog4_2_2to4_2_3.php
* Thu Mar 26 2009 dmueller@suse.de
- update to 4.2.2
  * see http://kde.org/announcements/changelogs/changelog4_2_1to4_2_2.php
* Sat Mar  7 2009 coolo@suse.de
- update 4.2 branch to add stdio.h
* Fri Feb 27 2009 dmueller@suse.de
- update to 4.2.1
  * see http://kde.org/announcements/changelogs/changelog4_2_0to4_2_1.php
* Thu Feb 12 2009 dmueller@suse.de
- update branch diff again for marble
* Mon Feb  9 2009 dmueller@suse.de
- update branch diff again for marble
* Sun Feb  8 2009 stbinner@suse.de
- update branch diff: fix Designer crash due to Marble plugin
* Thu Feb  5 2009 stbinner@suse.de
- fix -noarch build on ppc64
* Thu Jan 22 2009 dmueller@suse.de
- update to 4.2.0
* Tue Jan 13 2009 dmueller@suse.de
- update to 4.1.96
* Sun Jan 11 2009 stbinner@suse.de
- update to 4.1.87 (KDE 4.2 Januar snapshot)
* Mon Dec  1 2008 ro@suse.de
- no ocaml on s390 and s390x (as on ppc ppc64)
* Thu Nov  6 2008 dmueller@suse.de
- fix kdeedu4-noarch buildrequires
* Wed Nov  5 2008 dmueller@suse.de
- use minimal-toc to fix build on ppc(64)
* Fri Oct 31 2008 dmueller@suse.de
- update to 4.1.3
  * see http://kde.org/announcements/changelogs/changelog4_1_2to4_1_3.php
* Thu Sep 25 2008 dmueller@suse.de
- update to 4.1.2
  * see http://kde.org/announcements/changelogs/changelog4_1_1to4_1_2.php
* Fri Sep  5 2008 stbinner@suse.de
- build separate kde4-kstars-data package again
* Thu Aug 28 2008 dmueller@suse.de
- update to 4.1.1
  * see http://kde.org/announcements/changelogs/changelog4_1to4_1_1.php
* Tue Aug 19 2008 stbinner@suse.de
- branch diff update: many Kalzium and Marble bug fixes
* Wed Aug 13 2008 dmueller@suse.de
- fix build
* Mon Aug  4 2008 dmueller@suse.de
- branch diff update
* Wed Jul 30 2008 dmueller@suse.de
- enable kde4-step build
* Wed Jul 23 2008 dmueller@suse.de
- update to 4.1.0
* Tue Jul 22 2008 dmueller@suse.de
- file list fix
* Thu Jul 17 2008 dmueller@suse.de
- update to 4.0.99
* Wed Jul  9 2008 dmueller@suse.de
- update to 4.0.98
* Mon Jul  7 2008 dmueller@suse.de
- fix kde4-marble maps packaging error
* Thu Jul  3 2008 dmueller@suse.de
- update to 4.0.85
* Tue Jul  1 2008 dmueller@suse.de
- fix filelist again
* Mon Jun 30 2008 dmueller@suse.de
- update filelist
* Thu Jun 26 2008 dmueller@suse.de
- update to 4.0.84
* Wed Jun 18 2008 dmueller@suse.de
- update to 4.0.83
* Tue Jun 10 2008 dmueller@suse.de
- update to 4.0.82
* Mon Jun  9 2008 dmueller@suse.de
- update to 4.0.81
* Thu May 29 2008 dmueller@suse.de
- make sure that the right version of kde4-marble-data is installed
  (kde#162254)
* Thu May  1 2008 dmueller@suse.de
- update to 4.0.4
  * http://www.kde.org/announcements/changelogs/changelog4_0_3to4_0_4.php
* Fri Apr 25 2008 dmueller@suse.de
- branch diff update
* Mon Apr 21 2008 stbinner@suse.de
- fix file lists
- branch diff update
* Thu Mar 27 2008 dmueller@suse.de
- update to 4.0.3
* Tue Mar 11 2008 dmueller@suse.de
- 4_0_BRANCH.diff update:
  * include fullscreen window handling fixes
* Wed Feb 27 2008 dmueller@suse.de
- update to 4.0.2
* Wed Feb 27 2008 dmueller@suse.de
- update branch diff, add pre_checkin to make upgrade easier
* Thu Jan 31 2008 dmueller@suse.de
- update to 4.0.1
* Sun Jan 20 2008 stbinner@suse.de
- update KDE_4_0_BRANCH.diff
* Sat Jan  5 2008 dmueller@suse.de
- update to 4.0
* Wed Jan  2 2008 stbinner@suse.de
- update to 3.97.2
* Fri Dec 21 2007 stbinner@suse.de
- fix file conflict
* Sun Dec 16 2007 dmueller@suse.de
- update to 3.97.1
* Thu Dec  6 2007 dmueller@suse.de
- adjust desktop files
* Wed Dec  5 2007 dmueller@suse.de
- update to 3.97.0
* Tue Dec  4 2007 dmueller@suse.de
- update to 3.96.3
* Wed Nov 21 2007 dmueller@suse.de
- update to 3.96.1
* Wed Nov 14 2007 dmueller@suse.de
- update to 3.96.0
* Wed Nov  7 2007 dmueller@suse.de
- update to 3.95.2
* Mon Nov  5 2007 dmueller@suse.de
- fix build on ppc
* Thu Nov  1 2007 dmueller@suse.de
- update to 3.95.1
* Wed Oct 31 2007 dmueller@suse.de
- update to KDE 4.0 Beta4
* Sat Oct 20 2007 dmueller@suse.de
- update to 3.94.1
* Mon Oct  8 2007 dmueller@suse.de
- update to KDE 4.0 Beta 3
* Tue Oct  2 2007 stbinner@suse.de
- update to 3.93.0.svn720124
* Wed Sep 26 2007 stbinner@suse.de
- update to 3.93.0.svn717255
* Thu Sep 13 2007 stbinner@suse.de
- update to 3.93.0.svn712059
* Sat Sep  1 2007 stbinner@suse.de
- update to KDE 4.0 Beta 2
* Thu Aug 23 2007 stbinner@suse.de
- update to 3.92.0.svn703905
* Thu Aug 16 2007 stbinner@suse.de
- update to 3.92.0.svn700953
* Thu Aug  9 2007 stbinner@suse.de
- update to 3.92.0.svn697375
- fix file conflict
* Sun Jul 29 2007 stbinner@suse.de
- update to KDE 4.0 Beta 1
* Thu Jul 12 2007 stbinner@suse.de
- update to 3.91.0.svn685967
* Sat Jun 23 2007 stbinner@suse.de
- update to 3.90.1.svn678988
* Wed Jun 13 2007 dmueller@suse.de
- update buildrequires (ocaml-facile)
* Fri Jun  8 2007 stbinner@suse.de
- update to 3.90.1.svn670254
* Mon Jun  4 2007 stbinner@suse.de
- fix build
* Fri Jun  1 2007 coolo@suse.de
- simplify spec file by using macros from kde4-filesystem
* Wed May 30 2007 coolo@suse.de
- fix spec file after kdelibs moves
* Mon May 28 2007 dmueller@suse.de
- update to 3.90.1.svn668119
* Wed May 23 2007 stbinner@suse.de
- use %%fdupes
* Fri May 18 2007 dmueller@suse.de
- remove facile requirement from Factory
* Sun May 13 2007 schwab@suse.de
- Fix file list.
* Sat May 12 2007 schwab@suse.de
- Fix dependencies.
* Fri May 11 2007 stbinner@suse.de
- initial package in abuild
